#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.7
visibility:           public
id:                   bv-sized-1.0.7-8FaR5vGQvIoGcmLSe8TjBk
key:                  bv-sized-1.0.7-8FaR5vGQvIoGcmLSe8TjBk
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  c0d7374f93f1734c9275667aa95a3e5e
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bv-sized-1.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.7-8FaR5vGQvIoGcmLSe8TjBk
depends:
    base-4.18.2.1 bitwise-1.0.0.1-3OudrVPZ8vVLfPCjlGuFm6
    bytestring-0.11.5.3 deepseq-1.4.8.1
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.11.0-LZTfJTspZHiGY1CPTabQqW
    random-1.2.1.3-2fto0SX8B0n5d0nC1pFLHo
    th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

